<style>
    .nav {
        background-color: #4B6788;
        height: 40px;
        color: #ffffff;
        line-height: 40px;
        padding: 0 10px;
    }

    .nav a {
        color: #ffffff;
    }
</style>

<div class="nav">
    <div>欢迎你：{{ request.user.first_name }} <a href="{% url 'bee_django_user:user_logout' %}">退出</a></div>


</div>
<div class="nav">
    <div>
        <a href="{% url 'bee_django_user:user_list' %}">学生列表</a> |
        <a href="{% url 'bee_django_user:class_list' %}">班级列表</a> |
        <a href="{% url 'bee_django_user:group_list' %}">用户组权限</a> |
    </div>
</div>