{% extends "wenxuanshe_base.html" %}
{% block content %}

    <a href="{% url 'bee_django_course:user_course' request.user.id %}">课程</a>
    <a href="{% url 'customcourse:user_live_page' user_id=request.user.id %}">习琴</a>


{% endblock %}